@@ -21,7 +21,7 @@ HistoryInfoWindow::HistoryInfoWindow(QWidget *parent) :
     setCentralWidget(widget);
 }
 
-void HistoryInfoWindow::load(QString name)
+void HistoryInfoWindow::load(QString name, QString group)
 {
     QList <QString> list;
     int j = 0;
@@ -37,8 +37,12 @@ void HistoryInfoWindow::load(QString name)
     while(!list.isEmpty())
     {
         set.setNum(j+1);
-        lblSet[j]->setText("Set " + set + ": " + list.takeFirst() + " kg " +
-                           list.takeFirst() + " reps - " + list.takeFirst());
+        if(group != "Cardio")
+            lblSet[j]->setText("Set " + set + ": " + list.takeFirst() + " kg " +
+                                list.takeFirst() + " reps - " + list.takeFirst());
+        else
+            lblSet[j]->setText("Set " + set + ": " + list.takeFirst() + " km on " +
+                                list.takeFirst() + " - " + list.takeFirst());
 
         j++;
     }
