@@ -208,9 +208,9 @@ void InfoWindow::loadExercise(QString name)
 
     while(!list.isEmpty())
     {
-        status[i] = list.takeLast(); //remove status
-        reps[i] = list.takeLast();
-        weight[i] = list.takeLast();
+        status[i] = list.takeFirst(); //remove status
+        reps[i] = list.takeFirst();
+        weight[i] = list.takeFirst();
 
         i++;
     }
