@@ -17,9 +17,14 @@ class WeightWindow : public QMainWindow
     Q_OBJECT
 public:
     explicit WeightWindow(QWidget *parent = 0);
+
 signals:
+    void closed();
+    void landscape();
 
 public slots:
+    void sendClosed();
+    void sendLandscape();
 
 private:
     ListWindow *lw;
