@@ -257,7 +257,7 @@ QList <QString> XML::loadSettings()
     return readInfo;
 }
 
-void XML::saveDoneEx(QString group, QString name, QString kg, QString reps, QString status)
+void XML::saveFirstSet(QString group, QString name, QString kg, QString reps, QString status)
 {
     QDate date = QDate::currentDate();
     QString dateString = date.toString("dd-MM-yyyy");
@@ -292,10 +292,60 @@ void XML::saveDoneEx(QString group, QString name, QString kg, QString reps, QStr
 
 }
 
+void XML::updateHistory(QString name, QString set, QString kg, QString reps, QString status)
+{
+    QDate date = QDate::currentDate();
+    QString dateString = date.toString("dd-MM-yyyy");
+
+    QDomDocument doc( "Exercises" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/history.xml" );
+    if( !file.open( QIODevice::ReadWrite ) )
+      return;
+    if( !doc.setContent( &file ) )
+    {
+      file.close();
+      return;
+    }
+    file.remove();
+    file.close();
+    QDomElement root = doc.documentElement();
+    if( root.tagName() != "exercise" )
+      return;
+
+    QDomNode n = root.firstChild();
+    while( !n.isNull() )
+    {
+      QDomElement e = n.toElement();
+      if( !e.isNull() )
+      {
+        if( e.tagName() == "exercise" )
+        {
+            if(name == e.attribute( "name", "" ) && dateString == e.attribute("date",""))
+            {
+                e.setAttribute("variable" + set, kg);
+                e.setAttribute("reps" + set, reps);
+                e.setAttribute("status" + set, status);
+            }
+        }
+      }
+      n = n.nextSibling();
+   }
+
+    file.open( QIODevice::ReadWrite );
+
+    QTextStream ts( &file );
+    ts << doc.toString();
+    file.close();
+
+    return;
+}
+
 QList <QString> XML::getHistoryByExercise(QString name)
 {
     QList <QString> readInfo;
     QString lastDate;
+    QString j;
 
     QDomDocument doc( "Exercises" );
     QString str = "/home/user/.qexercise";
@@ -327,9 +377,13 @@ QList <QString> XML::getHistoryByExercise(QString name)
 
             if(e.attribute("name", "") == name && e.attribute("date", "") == lastDate)
             {
-                readInfo.append(e.attribute("variable", ""));
-                readInfo.append(e.attribute("reps", ""));
-                readInfo.append(e.attribute("status", ""));
+                for(int i = 1; i < 10; i++)
+                {
+                    j.setNum(i);
+                    readInfo.append(e.attribute("variable" + j, ""));
+                    readInfo.append(e.attribute("reps" + j, ""));
+                    readInfo.append(e.attribute("status" + j, ""));
+                }
             }
         }
 
@@ -977,14 +1031,42 @@ QDomElement XML::createFoodNode( QDomDocument &d, QString name, QString type, QS
 
 QDomElement XML::createHistoryNode( QDomDocument &d, QString group, QString name, QString date, QString kg, QString reps, QString status)
 {
+
    QDomElement cn = d.createElement( "exercise" );
 
    cn.setAttribute("group", group);
    cn.setAttribute("name", name);
    cn.setAttribute("date", date);
-   cn.setAttribute("variable", kg);
-   cn.setAttribute("reps", reps);
-   cn.setAttribute("status", status);
+
+   cn.setAttribute("variable1", kg);
+   cn.setAttribute("variable2", "0");
+   cn.setAttribute("variable3", "0");
+   cn.setAttribute("variable4", "0");
+   cn.setAttribute("variable5", "0");
+   cn.setAttribute("variable6", "0");
+   cn.setAttribute("variable7", "0");
+   cn.setAttribute("variable8", "0");
+   cn.setAttribute("variable9", "0");
+
+   cn.setAttribute("reps1", reps);
+   cn.setAttribute("reps2", "0");
+   cn.setAttribute("reps3", "0");
+   cn.setAttribute("reps4", "0");
+   cn.setAttribute("reps5", "0");
+   cn.setAttribute("reps6", "0");
+   cn.setAttribute("reps7", "0");
+   cn.setAttribute("reps8", "0");
+   cn.setAttribute("reps9", "0");
+
+   cn.setAttribute("status1", status);
+   cn.setAttribute("status2", "0");
+   cn.setAttribute("status3", "0");
+   cn.setAttribute("status4", "0");
+   cn.setAttribute("status5", "0");
+   cn.setAttribute("status6", "0");
+   cn.setAttribute("status7", "0");
+   cn.setAttribute("status8", "0");
+   cn.setAttribute("status9", "0");
 
    return cn;
 }
